# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.cryptography.certificates
import winsdk.windows.storage.streams

class Capi1KdfTargetAlgorithm(enum.IntEnum):
    NOT_AES = 0
    AES = 1

class CryptographicPadding(enum.IntEnum):
    NONE = 0
    RSA_OAEP = 1
    RSA_PKCS1_V15 = 2
    RSA_PSS = 3

class CryptographicPrivateKeyBlobType(enum.IntEnum):
    PKCS8_RAW_PRIVATE_KEY_INFO = 0
    PKCS1_RSA_PRIVATE_KEY = 1
    B_CRYPT_PRIVATE_KEY = 2
    CAPI1_PRIVATE_KEY = 3
    B_CRYPT_ECC_FULL_PRIVATE_KEY = 4

class CryptographicPublicKeyBlobType(enum.IntEnum):
    X509_SUBJECT_PUBLIC_KEY_INFO = 0
    PKCS1_RSA_PUBLIC_KEY = 1
    B_CRYPT_PUBLIC_KEY = 2
    CAPI1_PUBLIC_KEY = 3
    B_CRYPT_ECC_FULL_PUBLIC_KEY = 4

Self = typing.TypeVar('Self')

class AsymmetricAlgorithmNames(winsdk.system.Object):
    ecdsa_p521_sha512: typing.ClassVar[str]
    dsa_sha1: typing.ClassVar[str]
    dsa_sha256: typing.ClassVar[str]
    ecdsa_p256_sha256: typing.ClassVar[str]
    ecdsa_p384_sha384: typing.ClassVar[str]
    rsa_sign_pkcs1_sha256: typing.ClassVar[str]
    rsa_oaep_sha1: typing.ClassVar[str]
    rsa_oaep_sha256: typing.ClassVar[str]
    rsa_oaep_sha384: typing.ClassVar[str]
    rsa_oaep_sha512: typing.ClassVar[str]
    rsa_pkcs1: typing.ClassVar[str]
    rsa_sign_pkcs1_sha1: typing.ClassVar[str]
    rsa_sign_pkcs1_sha384: typing.ClassVar[str]
    rsa_sign_pkcs1_sha512: typing.ClassVar[str]
    rsa_sign_pss_sha1: typing.ClassVar[str]
    rsa_sign_pss_sha256: typing.ClassVar[str]
    rsa_sign_pss_sha384: typing.ClassVar[str]
    rsa_sign_pss_sha512: typing.ClassVar[str]
    ecdsa_sha384: typing.ClassVar[str]
    ecdsa_sha512: typing.ClassVar[str]
    ecdsa_sha256: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AsymmetricAlgorithmNames: ...

class AsymmetricKeyAlgorithmProvider(winsdk.system.Object):
    algorithm_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AsymmetricKeyAlgorithmProvider: ...
    def create_key_pair(self, key_size: winsdk.system.UInt32) -> typing.Optional[CryptographicKey]: ...
    def create_key_pair_with_curve_name(self, curve_name: str) -> typing.Optional[CryptographicKey]: ...
    def create_key_pair_with_curve_parameters(self, parameters: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[CryptographicKey]: ...
    @typing.overload
    def import_key_pair(self, key_blob: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicKey]: ...
    @typing.overload
    def import_key_pair(self, key_blob: typing.Optional[winsdk.windows.storage.streams.IBuffer], blob_type: CryptographicPrivateKeyBlobType) -> typing.Optional[CryptographicKey]: ...
    @typing.overload
    def import_public_key(self, key_blob: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicKey]: ...
    @typing.overload
    def import_public_key(self, key_blob: typing.Optional[winsdk.windows.storage.streams.IBuffer], blob_type: CryptographicPublicKeyBlobType) -> typing.Optional[CryptographicKey]: ...
    @staticmethod
    def open_algorithm(algorithm: str) -> typing.Optional[AsymmetricKeyAlgorithmProvider]: ...

class CryptographicEngine(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CryptographicEngine: ...
    @staticmethod
    def decrypt(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], iv: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def decrypt_and_authenticate(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], nonce: typing.Optional[winsdk.windows.storage.streams.IBuffer], authentication_tag: typing.Optional[winsdk.windows.storage.streams.IBuffer], authenticated_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def decrypt_async(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], iv: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def derive_key_material(key: typing.Optional[CryptographicKey], parameters: typing.Optional[KeyDerivationParameters], desired_key_size: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def encrypt(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], iv: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def encrypt_and_authenticate(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], nonce: typing.Optional[winsdk.windows.storage.streams.IBuffer], authenticated_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[EncryptedAndAuthenticatedData]: ...
    @staticmethod
    def sign(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def sign_async(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def sign_hashed_data(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def sign_hashed_data_async(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def verify_signature(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], signature: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.system.Boolean: ...
    @staticmethod
    def verify_signature_with_hash_input(key: typing.Optional[CryptographicKey], data: typing.Optional[winsdk.windows.storage.streams.IBuffer], signature: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.system.Boolean: ...

class CryptographicHash(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CryptographicHash: ...
    def append(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> None: ...
    def get_value_and_reset(self) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...

class CryptographicKey(winsdk.system.Object):
    key_size: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CryptographicKey: ...
    @typing.overload
    def export(self) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    def export(self, blob_type: CryptographicPrivateKeyBlobType) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    def export_public_key(self) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    def export_public_key(self, blob_type: CryptographicPublicKeyBlobType) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...

class EccCurveNames(winsdk.system.Object):
    all_ecc_curve_names: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    brainpool_p160r1: typing.ClassVar[str]
    brainpool_p160t1: typing.ClassVar[str]
    brainpool_p192r1: typing.ClassVar[str]
    brainpool_p192t1: typing.ClassVar[str]
    brainpool_p224r1: typing.ClassVar[str]
    brainpool_p224t1: typing.ClassVar[str]
    brainpool_p256r1: typing.ClassVar[str]
    brainpool_p256t1: typing.ClassVar[str]
    brainpool_p320r1: typing.ClassVar[str]
    brainpool_p320t1: typing.ClassVar[str]
    brainpool_p384r1: typing.ClassVar[str]
    brainpool_p384t1: typing.ClassVar[str]
    brainpool_p512r1: typing.ClassVar[str]
    brainpool_p512t1: typing.ClassVar[str]
    curve25519: typing.ClassVar[str]
    ec192wapi: typing.ClassVar[str]
    nist_p192: typing.ClassVar[str]
    nist_p224: typing.ClassVar[str]
    nist_p256: typing.ClassVar[str]
    nist_p384: typing.ClassVar[str]
    nist_p521: typing.ClassVar[str]
    nums_p256t1: typing.ClassVar[str]
    nums_p384t1: typing.ClassVar[str]
    nums_p512t1: typing.ClassVar[str]
    sec_p160k1: typing.ClassVar[str]
    sec_p160r1: typing.ClassVar[str]
    sec_p160r2: typing.ClassVar[str]
    sec_p192k1: typing.ClassVar[str]
    sec_p192r1: typing.ClassVar[str]
    sec_p224k1: typing.ClassVar[str]
    sec_p224r1: typing.ClassVar[str]
    sec_p256k1: typing.ClassVar[str]
    sec_p256r1: typing.ClassVar[str]
    sec_p384r1: typing.ClassVar[str]
    sec_p521r1: typing.ClassVar[str]
    wtls12: typing.ClassVar[str]
    wtls7: typing.ClassVar[str]
    wtls9: typing.ClassVar[str]
    x962_p192v1: typing.ClassVar[str]
    x962_p192v2: typing.ClassVar[str]
    x962_p192v3: typing.ClassVar[str]
    x962_p239v1: typing.ClassVar[str]
    x962_p239v2: typing.ClassVar[str]
    x962_p239v3: typing.ClassVar[str]
    x962_p256v1: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EccCurveNames: ...

class EncryptedAndAuthenticatedData(winsdk.system.Object):
    authentication_tag: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    encrypted_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EncryptedAndAuthenticatedData: ...

class HashAlgorithmNames(winsdk.system.Object):
    md5: typing.ClassVar[str]
    sha1: typing.ClassVar[str]
    sha256: typing.ClassVar[str]
    sha384: typing.ClassVar[str]
    sha512: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HashAlgorithmNames: ...

class HashAlgorithmProvider(winsdk.system.Object):
    algorithm_name: str
    hash_length: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HashAlgorithmProvider: ...
    def create_hash(self) -> typing.Optional[CryptographicHash]: ...
    def hash_data(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def open_algorithm(algorithm: str) -> typing.Optional[HashAlgorithmProvider]: ...

class KeyDerivationAlgorithmNames(winsdk.system.Object):
    pbkdf2_sha256: typing.ClassVar[str]
    pbkdf2_md5: typing.ClassVar[str]
    pbkdf2_sha1: typing.ClassVar[str]
    sp800108_ctr_hmac_sha512: typing.ClassVar[str]
    pbkdf2_sha384: typing.ClassVar[str]
    pbkdf2_sha512: typing.ClassVar[str]
    sp800108_ctr_hmac_md5: typing.ClassVar[str]
    sp800108_ctr_hmac_sha1: typing.ClassVar[str]
    sp800108_ctr_hmac_sha256: typing.ClassVar[str]
    sp800108_ctr_hmac_sha384: typing.ClassVar[str]
    sp80056a_concat_md5: typing.ClassVar[str]
    sp80056a_concat_sha1: typing.ClassVar[str]
    sp80056a_concat_sha256: typing.ClassVar[str]
    sp80056a_concat_sha384: typing.ClassVar[str]
    sp80056a_concat_sha512: typing.ClassVar[str]
    capi_kdf_sha1: typing.ClassVar[str]
    capi_kdf_sha256: typing.ClassVar[str]
    capi_kdf_sha384: typing.ClassVar[str]
    capi_kdf_sha512: typing.ClassVar[str]
    capi_kdf_md5: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KeyDerivationAlgorithmNames: ...

class KeyDerivationAlgorithmProvider(winsdk.system.Object):
    algorithm_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KeyDerivationAlgorithmProvider: ...
    def create_key(self, key_material: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicKey]: ...
    @staticmethod
    def open_algorithm(algorithm: str) -> typing.Optional[KeyDerivationAlgorithmProvider]: ...

class KeyDerivationParameters(winsdk.system.Object):
    kdf_generic_binary: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    iteration_count: winsdk.system.UInt32
    capi1_kdf_target_algorithm: Capi1KdfTargetAlgorithm
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KeyDerivationParameters: ...
    @staticmethod
    def build_for_capi1_kdf(capi1_kdf_target_algorithm: Capi1KdfTargetAlgorithm) -> typing.Optional[KeyDerivationParameters]: ...
    @staticmethod
    def build_for_pbkdf2(pbkdf2_salt: typing.Optional[winsdk.windows.storage.streams.IBuffer], iteration_count: winsdk.system.UInt32) -> typing.Optional[KeyDerivationParameters]: ...
    @staticmethod
    def build_for_s_p800108(label: typing.Optional[winsdk.windows.storage.streams.IBuffer], context: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[KeyDerivationParameters]: ...
    @staticmethod
    def build_for_s_p80056a(algorithm_id: typing.Optional[winsdk.windows.storage.streams.IBuffer], party_u_info: typing.Optional[winsdk.windows.storage.streams.IBuffer], party_v_info: typing.Optional[winsdk.windows.storage.streams.IBuffer], supp_pub_info: typing.Optional[winsdk.windows.storage.streams.IBuffer], supp_priv_info: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[KeyDerivationParameters]: ...

class MacAlgorithmNames(winsdk.system.Object):
    aes_cmac: typing.ClassVar[str]
    hmac_md5: typing.ClassVar[str]
    hmac_sha1: typing.ClassVar[str]
    hmac_sha256: typing.ClassVar[str]
    hmac_sha384: typing.ClassVar[str]
    hmac_sha512: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MacAlgorithmNames: ...

class MacAlgorithmProvider(winsdk.system.Object):
    algorithm_name: str
    mac_length: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MacAlgorithmProvider: ...
    def create_hash(self, key_material: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicHash]: ...
    def create_key(self, key_material: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicKey]: ...
    @staticmethod
    def open_algorithm(algorithm: str) -> typing.Optional[MacAlgorithmProvider]: ...

class PersistedKeyProvider(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PersistedKeyProvider: ...
    @staticmethod
    def open_key_pair_from_certificate_async(certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate], hash_algorithm_name: str, padding: CryptographicPadding) -> winsdk.windows.foundation.IAsyncOperation[CryptographicKey]: ...
    @staticmethod
    def open_public_key_from_certificate(certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate], hash_algorithm_name: str, padding: CryptographicPadding) -> typing.Optional[CryptographicKey]: ...

class SymmetricAlgorithmNames(winsdk.system.Object):
    aes_cbc: typing.ClassVar[str]
    aes_cbc_pkcs7: typing.ClassVar[str]
    aes_ccm: typing.ClassVar[str]
    aes_ecb: typing.ClassVar[str]
    aes_ecb_pkcs7: typing.ClassVar[str]
    aes_gcm: typing.ClassVar[str]
    des_cbc: typing.ClassVar[str]
    des_cbc_pkcs7: typing.ClassVar[str]
    des_ecb: typing.ClassVar[str]
    des_ecb_pkcs7: typing.ClassVar[str]
    rc2_cbc: typing.ClassVar[str]
    rc2_cbc_pkcs7: typing.ClassVar[str]
    rc2_ecb: typing.ClassVar[str]
    rc2_ecb_pkcs7: typing.ClassVar[str]
    rc4: typing.ClassVar[str]
    triple_des_cbc: typing.ClassVar[str]
    triple_des_cbc_pkcs7: typing.ClassVar[str]
    triple_des_ecb: typing.ClassVar[str]
    triple_des_ecb_pkcs7: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SymmetricAlgorithmNames: ...

class SymmetricKeyAlgorithmProvider(winsdk.system.Object):
    algorithm_name: str
    block_length: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SymmetricKeyAlgorithmProvider: ...
    def create_symmetric_key(self, key_material: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[CryptographicKey]: ...
    @staticmethod
    def open_algorithm(algorithm: str) -> typing.Optional[SymmetricKeyAlgorithmProvider]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.graphics.imaging

Self = typing.TypeVar('Self')

class InkWorkspaceHostedAppManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkWorkspaceHostedAppManager: ...
    @staticmethod
    def get_for_current_app() -> typing.Optional[InkWorkspaceHostedAppManager]: ...
    def set_thumbnail_async(self, bitmap: typing.Optional[winsdk.windows.graphics.imaging.SoftwareBitmap]) -> winsdk.windows.foundation.IAsyncAction: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Contacts.Provider")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class AddContactResult(enum.IntEnum):
    ADDED = 0
    ALREADY_ADDED = 1
    UNAVAILABLE = 2

_ns_module._register_AddContactResult(AddContactResult)

ContactPickerUI = _ns_module.ContactPickerUI
ContactRemovedEventArgs = _ns_module.ContactRemovedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class TargetedContentAppInstallationState(enum.IntEnum):
    NOT_APPLICABLE = 0
    NOT_INSTALLED = 1
    INSTALLED = 2

class TargetedContentAvailability(enum.IntEnum):
    NONE = 0
    PARTIAL = 1
    ALL = 2

class TargetedContentInteraction(enum.IntEnum):
    IMPRESSION = 0
    CLICK_THROUGH = 1
    HOVER = 2
    LIKE = 3
    DISLIKE = 4
    DISMISS = 5
    INELIGIBLE = 6
    ACCEPT = 7
    DECLINE = 8
    DEFER = 9
    CANCELED = 10
    CONVERSION = 11
    OPPORTUNITY = 12

class TargetedContentObjectKind(enum.IntEnum):
    COLLECTION = 0
    ITEM = 1
    VALUE = 2

class TargetedContentValueKind(enum.IntEnum):
    STRING = 0
    URI = 1
    NUMBER = 2
    BOOLEAN = 3
    FILE = 4
    IMAGE_FILE = 5
    ACTION = 6
    STRINGS = 7
    URIS = 8
    NUMBERS = 9
    BOOLEANS = 10
    FILES = 11
    IMAGE_FILES = 12
    ACTIONS = 13

Self = typing.TypeVar('Self')

class TargetedContentAction(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentAction: ...
    def invoke_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class TargetedContentAvailabilityChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentAvailabilityChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class TargetedContentChangedEventArgs(winsdk.system.Object):
    has_previous_content_expired: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class TargetedContentCollection(winsdk.system.Object):
    collections: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentCollection]]
    id: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentItem]]
    path: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, TargetedContentValue]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentCollection: ...
    def report_custom_interaction(self, custom_interaction_name: str) -> None: ...
    def report_interaction(self, interaction: TargetedContentInteraction) -> None: ...

class TargetedContentContainer(winsdk.system.Object):
    availability: TargetedContentAvailability
    content: typing.Optional[TargetedContentCollection]
    id: str
    timestamp: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentContainer: ...
    @staticmethod
    def get_async(content_id: str) -> winsdk.windows.foundation.IAsyncOperation[TargetedContentContainer]: ...
    def select_single_object(self, path: str) -> typing.Optional[TargetedContentObject]: ...

class TargetedContentFile(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentFile: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...

class TargetedContentImage(winsdk.system.Object):
    height: winsdk.system.UInt32
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentImage: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...

class TargetedContentItem(winsdk.system.Object):
    collections: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentCollection]]
    path: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, TargetedContentValue]]
    state: typing.Optional[TargetedContentItemState]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentItem: ...
    def report_custom_interaction(self, custom_interaction_name: str) -> None: ...
    def report_interaction(self, interaction: TargetedContentInteraction) -> None: ...

class TargetedContentItemState(winsdk.system.Object):
    app_installation_state: TargetedContentAppInstallationState
    should_display: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentItemState: ...

class TargetedContentObject(winsdk.system.Object):
    collection: typing.Optional[TargetedContentCollection]
    item: typing.Optional[TargetedContentItem]
    object_kind: TargetedContentObjectKind
    value: typing.Optional[TargetedContentValue]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentObject: ...

class TargetedContentStateChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentStateChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class TargetedContentSubscription(winsdk.system.Object):
    id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentSubscription: ...
    @staticmethod
    def get_async(subscription_id: str) -> winsdk.windows.foundation.IAsyncOperation[TargetedContentSubscription]: ...
    def get_content_container_async(self) -> winsdk.windows.foundation.IAsyncOperation[TargetedContentContainer]: ...
    @staticmethod
    def get_options(subscription_id: str) -> typing.Optional[TargetedContentSubscriptionOptions]: ...
    def add_availability_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[TargetedContentSubscription, TargetedContentAvailabilityChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_availability_changed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_content_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[TargetedContentSubscription, TargetedContentChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_content_changed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[TargetedContentSubscription, TargetedContentStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class TargetedContentSubscriptionOptions(winsdk.system.Object):
    allow_partial_content_availability: winsdk.system.Boolean
    cloud_query_parameters: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    local_filters: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    subscription_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentSubscriptionOptions: ...
    def update(self) -> None: ...

class TargetedContentValue(winsdk.system.Object):
    action: typing.Optional[TargetedContentAction]
    actions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentAction]]
    boolean: winsdk.system.Boolean
    booleans: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Boolean]]
    file: typing.Optional[TargetedContentFile]
    files: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentFile]]
    image_file: typing.Optional[TargetedContentImage]
    image_files: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TargetedContentImage]]
    number: winsdk.system.Double
    numbers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Double]]
    path: str
    string: str
    strings: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    value_kind: TargetedContentValueKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetedContentValue: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui.input.inking

class InkAnalysisDrawingKind(enum.IntEnum):
    DRAWING = 0
    CIRCLE = 1
    ELLIPSE = 2
    TRIANGLE = 3
    ISOSCELES_TRIANGLE = 4
    EQUILATERAL_TRIANGLE = 5
    RIGHT_TRIANGLE = 6
    QUADRILATERAL = 7
    RECTANGLE = 8
    SQUARE = 9
    DIAMOND = 10
    TRAPEZOID = 11
    PARALLELOGRAM = 12
    PENTAGON = 13
    HEXAGON = 14

class InkAnalysisNodeKind(enum.IntEnum):
    UNCLASSIFIED_INK = 0
    ROOT = 1
    WRITING_REGION = 2
    PARAGRAPH = 3
    LINE = 4
    INK_WORD = 5
    INK_BULLET = 6
    INK_DRAWING = 7
    LIST_ITEM = 8

class InkAnalysisStatus(enum.IntEnum):
    UPDATED = 0
    UNCHANGED = 1

class InkAnalysisStrokeKind(enum.IntEnum):
    AUTO = 0
    WRITING = 1
    DRAWING = 2

Self = typing.TypeVar('Self')

class InkAnalysisInkBullet(winsdk.system.Object):
    recognized_text: str
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisInkBullet: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisInkDrawing(winsdk.system.Object):
    center: winsdk.windows.foundation.Point
    drawing_kind: InkAnalysisDrawingKind
    points: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisInkDrawing: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisInkWord(winsdk.system.Object):
    recognized_text: str
    text_alternates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisInkWord: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisLine(winsdk.system.Object):
    indent_level: winsdk.system.Int32
    recognized_text: str
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisLine: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisListItem(winsdk.system.Object):
    recognized_text: str
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisListItem: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisNode(winsdk.system.Object):
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisNode: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisParagraph(winsdk.system.Object):
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    recognized_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisParagraph: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisResult(winsdk.system.Object):
    status: InkAnalysisStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisResult: ...

class InkAnalysisRoot(winsdk.system.Object):
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    recognized_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisRoot: ...
    def find_nodes(self, node_kind: InkAnalysisNodeKind) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalysisWritingRegion(winsdk.system.Object):
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    recognized_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalysisWritingRegion: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class InkAnalyzer(winsdk.system.Object):
    analysis_root: typing.Optional[InkAnalysisRoot]
    is_analyzing: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InkAnalyzer: ...
    def __new__(cls: typing.Type[InkAnalyzer]) -> InkAnalyzer:...
    def add_data_for_stroke(self, stroke: typing.Optional[winsdk.windows.ui.input.inking.InkStroke]) -> None: ...
    def add_data_for_strokes(self, strokes: typing.Iterable[winsdk.windows.ui.input.inking.InkStroke]) -> None: ...
    def analyze_async(self) -> winsdk.windows.foundation.IAsyncOperation[InkAnalysisResult]: ...
    def clear_data_for_all_strokes(self) -> None: ...
    def remove_data_for_stroke(self, stroke_id: winsdk.system.UInt32) -> None: ...
    def remove_data_for_strokes(self, stroke_ids: typing.Iterable[winsdk.system.UInt32]) -> None: ...
    def replace_data_for_stroke(self, stroke: typing.Optional[winsdk.windows.ui.input.inking.InkStroke]) -> None: ...
    def set_stroke_data_kind(self, stroke_id: winsdk.system.UInt32, stroke_kind: InkAnalysisStrokeKind) -> None: ...

class IInkAnalysisNode(winsdk.system.Object):
    bounding_rect: winsdk.windows.foundation.Rect
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IInkAnalysisNode]]
    id: winsdk.system.UInt32
    kind: InkAnalysisNodeKind
    parent: typing.Optional[IInkAnalysisNode]
    rotated_bounding_rect: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Point]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IInkAnalysisNode: ...
    def get_stroke_ids(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class IInkAnalyzerFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IInkAnalyzerFactory: ...
    def create_analyzer(self) -> typing.Optional[InkAnalyzer]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Activation")

try:
    import winsdk.windows.applicationmodel.appointments.appointmentsprovider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.background
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.calls
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer.sharetarget
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.search
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.userdataaccounts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.wallet
except ImportError:
    pass

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.devices.printers.extensions
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.speechrecognition
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.pickers.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.search
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.notifications
except ImportError:
    pass

try:
    import winsdk.windows.ui.viewmanagement
except ImportError:
    pass

class ActivationKind(enum.IntEnum):
    LAUNCH = 0
    SEARCH = 1
    SHARE_TARGET = 2
    FILE = 3
    PROTOCOL = 4
    FILE_OPEN_PICKER = 5
    FILE_SAVE_PICKER = 6
    CACHED_FILE_UPDATER = 7
    CONTACT_PICKER = 8
    DEVICE = 9
    PRINT_TASK_SETTINGS = 10
    CAMERA_SETTINGS = 11
    RESTRICTED_LAUNCH = 12
    APPOINTMENTS_PROVIDER = 13
    CONTACT = 14
    LOCK_SCREEN_CALL = 15
    VOICE_COMMAND = 16
    LOCK_SCREEN = 17
    PICKER_RETURNED = 1000
    WALLET_ACTION = 1001
    PICK_FILE_CONTINUATION = 1002
    PICK_SAVE_FILE_CONTINUATION = 1003
    PICK_FOLDER_CONTINUATION = 1004
    WEB_AUTHENTICATION_BROKER_CONTINUATION = 1005
    WEB_ACCOUNT_PROVIDER = 1006
    COMPONENT_U_I = 1007
    PROTOCOL_FOR_RESULTS = 1009
    TOAST_NOTIFICATION = 1010
    PRINT3_D_WORKFLOW = 1011
    DIAL_RECEIVER = 1012
    DEVICE_PAIRING = 1013
    USER_DATA_ACCOUNTS_PROVIDER = 1014
    FILE_PICKER_EXPERIENCE = 1015
    LOCK_SCREEN_COMPONENT = 1016
    CONTACT_PANEL = 1017
    PRINT_WORKFLOW_FOREGROUND_TASK = 1018
    GAME_U_I_PROVIDER = 1019
    STARTUP_TASK = 1020
    COMMAND_LINE_LAUNCH = 1021
    BARCODE_SCANNER_PROVIDER = 1022
    PRINT_SUPPORT_JOB_U_I = 1023
    PRINT_SUPPORT_SETTINGS_U_I = 1024
    PHONE_CALL_ACTIVATION = 1025
    VPN_FOREGROUND = 1026

class ApplicationExecutionState(enum.IntEnum):
    NOT_RUNNING = 0
    RUNNING = 1
    SUSPENDED = 2
    TERMINATED = 3
    CLOSED_BY_USER = 4

_ns_module._register_ActivationKind(ActivationKind)
_ns_module._register_ApplicationExecutionState(ApplicationExecutionState)

AppointmentsProviderAddAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderAddAppointmentActivatedEventArgs
AppointmentsProviderRemoveAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderRemoveAppointmentActivatedEventArgs
AppointmentsProviderReplaceAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderReplaceAppointmentActivatedEventArgs
AppointmentsProviderShowAppointmentDetailsActivatedEventArgs = _ns_module.AppointmentsProviderShowAppointmentDetailsActivatedEventArgs
AppointmentsProviderShowTimeFrameActivatedEventArgs = _ns_module.AppointmentsProviderShowTimeFrameActivatedEventArgs
BackgroundActivatedEventArgs = _ns_module.BackgroundActivatedEventArgs
BarcodeScannerPreviewActivatedEventArgs = _ns_module.BarcodeScannerPreviewActivatedEventArgs
CachedFileUpdaterActivatedEventArgs = _ns_module.CachedFileUpdaterActivatedEventArgs
CameraSettingsActivatedEventArgs = _ns_module.CameraSettingsActivatedEventArgs
CommandLineActivatedEventArgs = _ns_module.CommandLineActivatedEventArgs
CommandLineActivationOperation = _ns_module.CommandLineActivationOperation
ContactCallActivatedEventArgs = _ns_module.ContactCallActivatedEventArgs
ContactMapActivatedEventArgs = _ns_module.ContactMapActivatedEventArgs
ContactMessageActivatedEventArgs = _ns_module.ContactMessageActivatedEventArgs
ContactPanelActivatedEventArgs = _ns_module.ContactPanelActivatedEventArgs
ContactPickerActivatedEventArgs = _ns_module.ContactPickerActivatedEventArgs
ContactPostActivatedEventArgs = _ns_module.ContactPostActivatedEventArgs
ContactVideoCallActivatedEventArgs = _ns_module.ContactVideoCallActivatedEventArgs
DeviceActivatedEventArgs = _ns_module.DeviceActivatedEventArgs
DevicePairingActivatedEventArgs = _ns_module.DevicePairingActivatedEventArgs
DialReceiverActivatedEventArgs = _ns_module.DialReceiverActivatedEventArgs
FileActivatedEventArgs = _ns_module.FileActivatedEventArgs
FileOpenPickerActivatedEventArgs = _ns_module.FileOpenPickerActivatedEventArgs
FileOpenPickerContinuationEventArgs = _ns_module.FileOpenPickerContinuationEventArgs
FileSavePickerActivatedEventArgs = _ns_module.FileSavePickerActivatedEventArgs
FileSavePickerContinuationEventArgs = _ns_module.FileSavePickerContinuationEventArgs
FolderPickerContinuationEventArgs = _ns_module.FolderPickerContinuationEventArgs
LaunchActivatedEventArgs = _ns_module.LaunchActivatedEventArgs
LockScreenActivatedEventArgs = _ns_module.LockScreenActivatedEventArgs
LockScreenCallActivatedEventArgs = _ns_module.LockScreenCallActivatedEventArgs
LockScreenComponentActivatedEventArgs = _ns_module.LockScreenComponentActivatedEventArgs
PhoneCallActivatedEventArgs = _ns_module.PhoneCallActivatedEventArgs
PickerReturnedActivatedEventArgs = _ns_module.PickerReturnedActivatedEventArgs
Print3DWorkflowActivatedEventArgs = _ns_module.Print3DWorkflowActivatedEventArgs
PrintTaskSettingsActivatedEventArgs = _ns_module.PrintTaskSettingsActivatedEventArgs
ProtocolActivatedEventArgs = _ns_module.ProtocolActivatedEventArgs
ProtocolForResultsActivatedEventArgs = _ns_module.ProtocolForResultsActivatedEventArgs
RestrictedLaunchActivatedEventArgs = _ns_module.RestrictedLaunchActivatedEventArgs
SearchActivatedEventArgs = _ns_module.SearchActivatedEventArgs
ShareTargetActivatedEventArgs = _ns_module.ShareTargetActivatedEventArgs
SplashScreen = _ns_module.SplashScreen
StartupTaskActivatedEventArgs = _ns_module.StartupTaskActivatedEventArgs
TileActivatedInfo = _ns_module.TileActivatedInfo
ToastNotificationActivatedEventArgs = _ns_module.ToastNotificationActivatedEventArgs
UserDataAccountProviderActivatedEventArgs = _ns_module.UserDataAccountProviderActivatedEventArgs
VoiceCommandActivatedEventArgs = _ns_module.VoiceCommandActivatedEventArgs
WalletActionActivatedEventArgs = _ns_module.WalletActionActivatedEventArgs
WebAccountProviderActivatedEventArgs = _ns_module.WebAccountProviderActivatedEventArgs
WebAuthenticationBrokerContinuationEventArgs = _ns_module.WebAuthenticationBrokerContinuationEventArgs
IActivatedEventArgs = _ns_module.IActivatedEventArgs
IActivatedEventArgsWithUser = _ns_module.IActivatedEventArgsWithUser
IApplicationViewActivatedEventArgs = _ns_module.IApplicationViewActivatedEventArgs
IAppointmentsProviderActivatedEventArgs = _ns_module.IAppointmentsProviderActivatedEventArgs
IAppointmentsProviderAddAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderAddAppointmentActivatedEventArgs
IAppointmentsProviderRemoveAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderRemoveAppointmentActivatedEventArgs
IAppointmentsProviderReplaceAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderReplaceAppointmentActivatedEventArgs
IAppointmentsProviderShowAppointmentDetailsActivatedEventArgs = _ns_module.IAppointmentsProviderShowAppointmentDetailsActivatedEventArgs
IAppointmentsProviderShowTimeFrameActivatedEventArgs = _ns_module.IAppointmentsProviderShowTimeFrameActivatedEventArgs
IBackgroundActivatedEventArgs = _ns_module.IBackgroundActivatedEventArgs
IBarcodeScannerPreviewActivatedEventArgs = _ns_module.IBarcodeScannerPreviewActivatedEventArgs
ICachedFileUpdaterActivatedEventArgs = _ns_module.ICachedFileUpdaterActivatedEventArgs
ICameraSettingsActivatedEventArgs = _ns_module.ICameraSettingsActivatedEventArgs
ICommandLineActivatedEventArgs = _ns_module.ICommandLineActivatedEventArgs
IContactActivatedEventArgs = _ns_module.IContactActivatedEventArgs
IContactCallActivatedEventArgs = _ns_module.IContactCallActivatedEventArgs
IContactMapActivatedEventArgs = _ns_module.IContactMapActivatedEventArgs
IContactMessageActivatedEventArgs = _ns_module.IContactMessageActivatedEventArgs
IContactPanelActivatedEventArgs = _ns_module.IContactPanelActivatedEventArgs
IContactPickerActivatedEventArgs = _ns_module.IContactPickerActivatedEventArgs
IContactPostActivatedEventArgs = _ns_module.IContactPostActivatedEventArgs
IContactVideoCallActivatedEventArgs = _ns_module.IContactVideoCallActivatedEventArgs
IContactsProviderActivatedEventArgs = _ns_module.IContactsProviderActivatedEventArgs
IContinuationActivatedEventArgs = _ns_module.IContinuationActivatedEventArgs
IDeviceActivatedEventArgs = _ns_module.IDeviceActivatedEventArgs
IDevicePairingActivatedEventArgs = _ns_module.IDevicePairingActivatedEventArgs
IDialReceiverActivatedEventArgs = _ns_module.IDialReceiverActivatedEventArgs
IFileActivatedEventArgs = _ns_module.IFileActivatedEventArgs
IFileActivatedEventArgsWithCallerPackageFamilyName = _ns_module.IFileActivatedEventArgsWithCallerPackageFamilyName
IFileActivatedEventArgsWithNeighboringFiles = _ns_module.IFileActivatedEventArgsWithNeighboringFiles
IFileOpenPickerActivatedEventArgs = _ns_module.IFileOpenPickerActivatedEventArgs
IFileOpenPickerActivatedEventArgs2 = _ns_module.IFileOpenPickerActivatedEventArgs2
IFileOpenPickerContinuationEventArgs = _ns_module.IFileOpenPickerContinuationEventArgs
IFileSavePickerActivatedEventArgs = _ns_module.IFileSavePickerActivatedEventArgs
IFileSavePickerActivatedEventArgs2 = _ns_module.IFileSavePickerActivatedEventArgs2
IFileSavePickerContinuationEventArgs = _ns_module.IFileSavePickerContinuationEventArgs
IFolderPickerContinuationEventArgs = _ns_module.IFolderPickerContinuationEventArgs
ILaunchActivatedEventArgs = _ns_module.ILaunchActivatedEventArgs
ILaunchActivatedEventArgs2 = _ns_module.ILaunchActivatedEventArgs2
ILockScreenActivatedEventArgs = _ns_module.ILockScreenActivatedEventArgs
ILockScreenCallActivatedEventArgs = _ns_module.ILockScreenCallActivatedEventArgs
IPhoneCallActivatedEventArgs = _ns_module.IPhoneCallActivatedEventArgs
IPickerReturnedActivatedEventArgs = _ns_module.IPickerReturnedActivatedEventArgs
IPrelaunchActivatedEventArgs = _ns_module.IPrelaunchActivatedEventArgs
IPrint3DWorkflowActivatedEventArgs = _ns_module.IPrint3DWorkflowActivatedEventArgs
IPrintTaskSettingsActivatedEventArgs = _ns_module.IPrintTaskSettingsActivatedEventArgs
IProtocolActivatedEventArgs = _ns_module.IProtocolActivatedEventArgs
IProtocolActivatedEventArgsWithCallerPackageFamilyNameAndData = _ns_module.IProtocolActivatedEventArgsWithCallerPackageFamilyNameAndData
IProtocolForResultsActivatedEventArgs = _ns_module.IProtocolForResultsActivatedEventArgs
IRestrictedLaunchActivatedEventArgs = _ns_module.IRestrictedLaunchActivatedEventArgs
ISearchActivatedEventArgs = _ns_module.ISearchActivatedEventArgs
ISearchActivatedEventArgsWithLinguisticDetails = _ns_module.ISearchActivatedEventArgsWithLinguisticDetails
IShareTargetActivatedEventArgs = _ns_module.IShareTargetActivatedEventArgs
IStartupTaskActivatedEventArgs = _ns_module.IStartupTaskActivatedEventArgs
IToastNotificationActivatedEventArgs = _ns_module.IToastNotificationActivatedEventArgs
IUserDataAccountProviderActivatedEventArgs = _ns_module.IUserDataAccountProviderActivatedEventArgs
IViewSwitcherProvider = _ns_module.IViewSwitcherProvider
IVoiceCommandActivatedEventArgs = _ns_module.IVoiceCommandActivatedEventArgs
IWalletActionActivatedEventArgs = _ns_module.IWalletActionActivatedEventArgs
IWebAccountProviderActivatedEventArgs = _ns_module.IWebAccountProviderActivatedEventArgs
IWebAuthenticationBrokerContinuationEventArgs = _ns_module.IWebAuthenticationBrokerContinuationEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation.collections

class JsonErrorStatus(enum.IntEnum):
    UNKNOWN = 0
    INVALID_JSON_STRING = 1
    INVALID_JSON_NUMBER = 2
    JSON_VALUE_NOT_FOUND = 3
    IMPLEMENTATION_LIMIT = 4

class JsonValueType(enum.IntEnum):
    NULL = 0
    BOOLEAN = 1
    NUMBER = 2
    STRING = 3
    ARRAY = 4
    OBJECT = 5

Self = typing.TypeVar('Self')

class JsonArray(winsdk.system.Object, typing.MutableSequence[IJsonValue]):
    value_type: JsonValueType
    size: winsdk.system.UInt32
    def __str__(self) -> str: ...
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> IJsonValue: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[IJsonValue]: ...
    def insert(self, index: int, value: IJsonValue) -> None: ...
    @typing.overload
    def __delitem__(self, index: int) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    @typing.overload
    def __setitem__(self, index: int, value: IJsonValue) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[IJsonValue]) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> JsonArray: ...
    def __new__(cls: typing.Type[JsonArray]) -> JsonArray:...
    def append(self, value: typing.Optional[IJsonValue]) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[IJsonValue]]: ...
    def get_array(self) -> typing.Optional[JsonArray]: ...
    def get_array_at(self, index: winsdk.system.UInt32) -> typing.Optional[JsonArray]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[IJsonValue]: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_boolean_at(self, index: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[IJsonValue]) -> winsdk.system.UInt32: ...
    def get_number(self) -> winsdk.system.Double: ...
    def get_number_at(self, index: winsdk.system.UInt32) -> winsdk.system.Double: ...
    def get_object(self) -> typing.Optional[JsonObject]: ...
    def get_object_at(self, index: winsdk.system.UInt32) -> typing.Optional[JsonObject]: ...
    def get_string(self) -> str: ...
    def get_string_at(self, index: winsdk.system.UInt32) -> str: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[IJsonValue]]: ...
    def index_of(self, value: typing.Optional[IJsonValue]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def insert_at(self, index: winsdk.system.UInt32, value: typing.Optional[IJsonValue]) -> None: ...
    @staticmethod
    def parse(input: str) -> typing.Optional[JsonArray]: ...
    def remove_at(self, index: winsdk.system.UInt32) -> None: ...
    def remove_at_end(self) -> None: ...
    def replace_all(self, items: winsdk.system.Array[IJsonValue]) -> None: ...
    def set_at(self, index: winsdk.system.UInt32, value: typing.Optional[IJsonValue]) -> None: ...
    def stringify(self) -> str: ...
    def to_string(self) -> str: ...
    @staticmethod
    def try_parse(input: str) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[JsonArray]]: ...

class JsonError(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> JsonError: ...
    @staticmethod
    def get_json_status(hresult: winsdk.system.Int32) -> JsonErrorStatus: ...

class JsonObject(winsdk.system.Object, typing.MutableMapping[str, IJsonValue]):
    value_type: JsonValueType
    size: winsdk.system.UInt32
    def __str__(self) -> str: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: IJsonValue) -> None: ...
    def __getitem__(self, key: str) -> IJsonValue: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> JsonObject: ...
    def __new__(cls: typing.Type[JsonObject]) -> JsonObject:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, IJsonValue]]]: ...
    def get_array(self) -> typing.Optional[JsonArray]: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_named_array(self, name: str) -> typing.Optional[JsonArray]: ...
    @typing.overload
    def get_named_array(self, name: str, default_value: typing.Optional[JsonArray]) -> typing.Optional[JsonArray]: ...
    @typing.overload
    def get_named_boolean(self, name: str) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_named_boolean(self, name: str, default_value: winsdk.system.Boolean) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_named_number(self, name: str) -> winsdk.system.Double: ...
    @typing.overload
    def get_named_number(self, name: str, default_value: winsdk.system.Double) -> winsdk.system.Double: ...
    @typing.overload
    def get_named_object(self, name: str) -> typing.Optional[JsonObject]: ...
    @typing.overload
    def get_named_object(self, name: str, default_value: typing.Optional[JsonObject]) -> typing.Optional[JsonObject]: ...
    @typing.overload
    def get_named_string(self, name: str) -> str: ...
    @typing.overload
    def get_named_string(self, name: str, default_value: str) -> str: ...
    @typing.overload
    def get_named_value(self, name: str) -> typing.Optional[JsonValue]: ...
    @typing.overload
    def get_named_value(self, name: str, default_value: typing.Optional[JsonValue]) -> typing.Optional[JsonValue]: ...
    def get_number(self) -> winsdk.system.Double: ...
    def get_object(self) -> typing.Optional[JsonObject]: ...
    def get_string(self) -> str: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IMapView[str, IJsonValue]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[IJsonValue]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[IJsonValue]: ...
    @staticmethod
    def parse(input: str) -> typing.Optional[JsonObject]: ...
    def remove(self, key: str) -> None: ...
    def set_named_value(self, name: str, value: typing.Optional[IJsonValue]) -> None: ...
    def stringify(self) -> str: ...
    def to_string(self) -> str: ...
    @staticmethod
    def try_parse(input: str) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[JsonObject]]: ...

class JsonValue(winsdk.system.Object):
    value_type: JsonValueType
    def __str__(self) -> str: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> JsonValue: ...
    @staticmethod
    def create_boolean_value(input: winsdk.system.Boolean) -> typing.Optional[JsonValue]: ...
    @staticmethod
    def create_null_value() -> typing.Optional[JsonValue]: ...
    @staticmethod
    def create_number_value(input: winsdk.system.Double) -> typing.Optional[JsonValue]: ...
    @staticmethod
    def create_string_value(input: str) -> typing.Optional[JsonValue]: ...
    def get_array(self) -> typing.Optional[JsonArray]: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_number(self) -> winsdk.system.Double: ...
    def get_object(self) -> typing.Optional[JsonObject]: ...
    def get_string(self) -> str: ...
    @staticmethod
    def parse(input: str) -> typing.Optional[JsonValue]: ...
    def stringify(self) -> str: ...
    def to_string(self) -> str: ...
    @staticmethod
    def try_parse(input: str) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[JsonValue]]: ...

class IJsonValue(winsdk.system.Object):
    value_type: JsonValueType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IJsonValue: ...
    def get_array(self) -> typing.Optional[JsonArray]: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_number(self) -> winsdk.system.Double: ...
    def get_object(self) -> typing.Optional[JsonObject]: ...
    def get_string(self) -> str: ...
    def stringify(self) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class UsbControlRecipient(enum.IntEnum):
    DEVICE = 0
    SPECIFIED_INTERFACE = 1
    ENDPOINT = 2
    OTHER = 3
    DEFAULT_INTERFACE = 4

class UsbControlTransferType(enum.IntEnum):
    STANDARD = 0
    CLASS = 1
    VENDOR = 2

class UsbEndpointType(enum.IntEnum):
    CONTROL = 0
    ISOCHRONOUS = 1
    BULK = 2
    INTERRUPT = 3

class UsbReadOptions(enum.IntFlag):
    NONE = 0
    AUTO_CLEAR_STALL = 0x1
    OVERRIDE_AUTOMATIC_BUFFER_MANAGEMENT = 0x2
    IGNORE_SHORT_PACKET = 0x4
    ALLOW_PARTIAL_READS = 0x8

class UsbTransferDirection(enum.IntEnum):
    OUT = 0
    IN = 1

class UsbWriteOptions(enum.IntFlag):
    NONE = 0
    AUTO_CLEAR_STALL = 0x1
    SHORT_PACKET_TERMINATE = 0x2

Self = typing.TypeVar('Self')

class UsbBulkInEndpointDescriptor(winsdk.system.Object):
    endpoint_number: winsdk.system.UInt8
    max_packet_size: winsdk.system.UInt32
    pipe: typing.Optional[UsbBulkInPipe]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbBulkInEndpointDescriptor: ...

class UsbBulkInPipe(winsdk.system.Object):
    read_options: UsbReadOptions
    endpoint_descriptor: typing.Optional[UsbBulkInEndpointDescriptor]
    input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]
    max_transfer_size_bytes: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbBulkInPipe: ...
    def clear_stall_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def flush_buffer(self) -> None: ...

class UsbBulkOutEndpointDescriptor(winsdk.system.Object):
    endpoint_number: winsdk.system.UInt8
    max_packet_size: winsdk.system.UInt32
    pipe: typing.Optional[UsbBulkOutPipe]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbBulkOutEndpointDescriptor: ...

class UsbBulkOutPipe(winsdk.system.Object):
    write_options: UsbWriteOptions
    endpoint_descriptor: typing.Optional[UsbBulkOutEndpointDescriptor]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbBulkOutPipe: ...
    def clear_stall_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UsbConfiguration(winsdk.system.Object):
    configuration_descriptor: typing.Optional[UsbConfigurationDescriptor]
    descriptors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbDescriptor]]
    usb_interfaces: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterface]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbConfiguration: ...

class UsbConfigurationDescriptor(winsdk.system.Object):
    configuration_value: winsdk.system.UInt8
    max_power_milliamps: winsdk.system.UInt32
    remote_wakeup: winsdk.system.Boolean
    self_powered: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbConfigurationDescriptor: ...
    @staticmethod
    def parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Optional[UsbConfigurationDescriptor]: ...
    @staticmethod
    def try_parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[UsbConfigurationDescriptor]]: ...

class UsbControlRequestType(winsdk.system.Object):
    recipient: UsbControlRecipient
    direction: UsbTransferDirection
    control_transfer_type: UsbControlTransferType
    as_byte: winsdk.system.UInt8
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbControlRequestType: ...
    def __new__(cls: typing.Type[UsbControlRequestType]) -> UsbControlRequestType:...

class UsbDescriptor(winsdk.system.Object):
    descriptor_type: winsdk.system.UInt8
    length: winsdk.system.UInt8
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbDescriptor: ...
    def read_descriptor_buffer(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> None: ...

class UsbDevice(winsdk.system.Object):
    configuration: typing.Optional[UsbConfiguration]
    default_interface: typing.Optional[UsbInterface]
    device_descriptor: typing.Optional[UsbDeviceDescriptor]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbDevice: ...
    def close(self) -> None: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[UsbDevice]: ...
    @staticmethod
    def get_device_class_selector(usb_class: typing.Optional[UsbDeviceClass]) -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(win_usb_interface_class: winsdk.system.Guid) -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(vendor_id: winsdk.system.UInt32, product_id: winsdk.system.UInt32) -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(vendor_id: winsdk.system.UInt32, product_id: winsdk.system.UInt32, win_usb_interface_class: winsdk.system.Guid) -> str: ...
    @typing.overload
    def send_control_in_transfer_async(self, setup_packet: typing.Optional[UsbSetupPacket]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    def send_control_in_transfer_async(self, setup_packet: typing.Optional[UsbSetupPacket], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    def send_control_out_transfer_async(self, setup_packet: typing.Optional[UsbSetupPacket]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...
    @typing.overload
    def send_control_out_transfer_async(self, setup_packet: typing.Optional[UsbSetupPacket], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...

class UsbDeviceClass(winsdk.system.Object):
    subclass_code: typing.Optional[typing.Optional[winsdk.system.UInt8]]
    protocol_code: typing.Optional[typing.Optional[winsdk.system.UInt8]]
    class_code: winsdk.system.UInt8
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbDeviceClass: ...
    def __new__(cls: typing.Type[UsbDeviceClass]) -> UsbDeviceClass:...

class UsbDeviceClasses(winsdk.system.Object):
    active_sync: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    cdc_control: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    device_firmware_update: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    irda: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    measurement: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    palm_sync: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    personal_healthcare: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    physical: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    vendor_specific: typing.ClassVar[typing.Optional[UsbDeviceClass]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbDeviceClasses: ...

class UsbDeviceDescriptor(winsdk.system.Object):
    bcd_device_revision: winsdk.system.UInt32
    bcd_usb: winsdk.system.UInt32
    max_packet_size0: winsdk.system.UInt8
    number_of_configurations: winsdk.system.UInt8
    product_id: winsdk.system.UInt32
    vendor_id: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbDeviceDescriptor: ...

class UsbEndpointDescriptor(winsdk.system.Object):
    as_bulk_in_endpoint_descriptor: typing.Optional[UsbBulkInEndpointDescriptor]
    as_bulk_out_endpoint_descriptor: typing.Optional[UsbBulkOutEndpointDescriptor]
    as_interrupt_in_endpoint_descriptor: typing.Optional[UsbInterruptInEndpointDescriptor]
    as_interrupt_out_endpoint_descriptor: typing.Optional[UsbInterruptOutEndpointDescriptor]
    direction: UsbTransferDirection
    endpoint_number: winsdk.system.UInt8
    endpoint_type: UsbEndpointType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbEndpointDescriptor: ...
    @staticmethod
    def parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Optional[UsbEndpointDescriptor]: ...
    @staticmethod
    def try_parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[UsbEndpointDescriptor]]: ...

class UsbInterface(winsdk.system.Object):
    bulk_in_pipes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbBulkInPipe]]
    bulk_out_pipes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbBulkOutPipe]]
    descriptors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbDescriptor]]
    interface_number: winsdk.system.UInt8
    interface_settings: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterfaceSetting]]
    interrupt_in_pipes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterruptInPipe]]
    interrupt_out_pipes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterruptOutPipe]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterface: ...

class UsbInterfaceDescriptor(winsdk.system.Object):
    alternate_setting_number: winsdk.system.UInt8
    class_code: winsdk.system.UInt8
    interface_number: winsdk.system.UInt8
    protocol_code: winsdk.system.UInt8
    subclass_code: winsdk.system.UInt8
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterfaceDescriptor: ...
    @staticmethod
    def parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Optional[UsbInterfaceDescriptor]: ...
    @staticmethod
    def try_parse(descriptor: typing.Optional[UsbDescriptor]) -> typing.Tuple[winsdk.system.Boolean, typing.Optional[UsbInterfaceDescriptor]]: ...

class UsbInterfaceSetting(winsdk.system.Object):
    bulk_in_endpoints: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbBulkInEndpointDescriptor]]
    bulk_out_endpoints: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbBulkOutEndpointDescriptor]]
    descriptors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbDescriptor]]
    interface_descriptor: typing.Optional[UsbInterfaceDescriptor]
    interrupt_in_endpoints: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterruptInEndpointDescriptor]]
    interrupt_out_endpoints: typing.Optional[winsdk.windows.foundation.collections.IVectorView[UsbInterruptOutEndpointDescriptor]]
    selected: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterfaceSetting: ...
    def select_setting_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UsbInterruptInEndpointDescriptor(winsdk.system.Object):
    endpoint_number: winsdk.system.UInt8
    interval: datetime.timedelta
    max_packet_size: winsdk.system.UInt32
    pipe: typing.Optional[UsbInterruptInPipe]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterruptInEndpointDescriptor: ...

class UsbInterruptInEventArgs(winsdk.system.Object):
    interrupt_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterruptInEventArgs: ...

class UsbInterruptInPipe(winsdk.system.Object):
    endpoint_descriptor: typing.Optional[UsbInterruptInEndpointDescriptor]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterruptInPipe: ...
    def clear_stall_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_data_received(self, handler: winsdk.windows.foundation.TypedEventHandler[UsbInterruptInPipe, UsbInterruptInEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_data_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UsbInterruptOutEndpointDescriptor(winsdk.system.Object):
    endpoint_number: winsdk.system.UInt8
    interval: datetime.timedelta
    max_packet_size: winsdk.system.UInt32
    pipe: typing.Optional[UsbInterruptOutPipe]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterruptOutEndpointDescriptor: ...

class UsbInterruptOutPipe(winsdk.system.Object):
    write_options: UsbWriteOptions
    endpoint_descriptor: typing.Optional[UsbInterruptOutEndpointDescriptor]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbInterruptOutPipe: ...
    def clear_stall_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UsbSetupPacket(winsdk.system.Object):
    value: winsdk.system.UInt32
    request_type: typing.Optional[UsbControlRequestType]
    request: winsdk.system.UInt8
    length: winsdk.system.UInt32
    index: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UsbSetupPacket: ...
    @typing.overload
    def __new__(cls: typing.Type[UsbSetupPacket], eight_byte_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> UsbSetupPacket:...
    @typing.overload
    def __new__(cls: typing.Type[UsbSetupPacket]) -> UsbSetupPacket:...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.activation
import winsdk.windows.applicationmodel.core
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.system

class AddResourcePackageOptions(enum.IntFlag):
    NONE = 0
    FORCE_TARGET_APP_SHUTDOWN = 0x1
    APPLY_UPDATE_IF_AVAILABLE = 0x2

class AppExecutionContext(enum.IntEnum):
    UNKNOWN = 0
    HOST = 1
    GUEST = 2

class AppInstallerPolicySource(enum.IntEnum):
    DEFAULT = 0
    SYSTEM = 1

class FullTrustLaunchResult(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    FILE_NOT_FOUND = 2
    UNKNOWN = 3

class LimitedAccessFeatureStatus(enum.IntEnum):
    UNAVAILABLE = 0
    AVAILABLE = 1
    AVAILABLE_WITHOUT_TOKEN = 2
    UNKNOWN = 3

class PackageContentGroupState(enum.IntEnum):
    NOT_STAGED = 0
    QUEUED = 1
    STAGING = 2
    STAGED = 3

class PackageRelationship(enum.IntEnum):
    DEPENDENCIES = 0
    DEPENDENTS = 1
    ALL = 2

class PackageSignatureKind(enum.IntEnum):
    NONE = 0
    DEVELOPER = 1
    ENTERPRISE = 2
    STORE = 3
    SYSTEM = 4

class PackageUpdateAvailability(enum.IntEnum):
    UNKNOWN = 0
    NO_UPDATES = 1
    AVAILABLE = 2
    REQUIRED = 3
    ERROR = 4

class StartupTaskState(enum.IntEnum):
    DISABLED = 0
    DISABLED_BY_USER = 1
    ENABLED = 2
    DISABLED_BY_POLICY = 3
    ENABLED_BY_POLICY = 4

Self = typing.TypeVar('Self')

class PackageInstallProgress:
    percent_complete: winsdk.system.UInt32
    def __new__(cls: typing.Type[PackageInstallProgress], percent_complete: winsdk.system.UInt32) -> PackageInstallProgress: ...

class PackageVersion:
    major: winsdk.system.UInt16
    minor: winsdk.system.UInt16
    build: winsdk.system.UInt16
    revision: winsdk.system.UInt16
    def __new__(cls: typing.Type[PackageVersion], major: winsdk.system.UInt16, minor: winsdk.system.UInt16, build: winsdk.system.UInt16, revision: winsdk.system.UInt16) -> PackageVersion: ...

class AppDisplayInfo(winsdk.system.Object):
    description: str
    display_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppDisplayInfo: ...
    def get_logo(self, size: winsdk.windows.foundation.Size) -> typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...

class AppInfo(winsdk.system.Object):
    app_user_model_id: str
    display_info: typing.Optional[AppDisplayInfo]
    id: str
    package_family_name: str
    package: typing.Optional[Package]
    execution_context: AppExecutionContext
    supported_file_extensions: str
    current: typing.ClassVar[typing.Optional[AppInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInfo: ...
    @staticmethod
    def get_from_app_user_model_id(app_user_model_id: str) -> typing.Optional[AppInfo]: ...
    @staticmethod
    def get_from_app_user_model_id_for_user(user: typing.Optional[winsdk.windows.system.User], app_user_model_id: str) -> typing.Optional[AppInfo]: ...

class AppInstallerInfo(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    automatic_background_task: winsdk.system.Boolean
    dependency_package_uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    force_update_from_any_version: winsdk.system.Boolean
    hours_between_update_checks: winsdk.system.UInt32
    is_auto_repair_enabled: winsdk.system.Boolean
    last_checked: datetime.datetime
    on_launch: winsdk.system.Boolean
    optional_package_uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    paused_until: typing.Optional[typing.Optional[datetime.datetime]]
    policy_source: AppInstallerPolicySource
    repair_uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    show_prompt: winsdk.system.Boolean
    update_blocks_activation: winsdk.system.Boolean
    update_uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    version: PackageVersion
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallerInfo: ...

class AppInstance(winsdk.system.Object):
    is_current_instance: winsdk.system.Boolean
    key: str
    recommended_instance: typing.ClassVar[typing.Optional[AppInstance]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstance: ...
    @staticmethod
    def find_or_register_instance_for_key(key: str) -> typing.Optional[AppInstance]: ...
    @staticmethod
    def get_activated_event_args() -> typing.Optional[winsdk.windows.applicationmodel.activation.IActivatedEventArgs]: ...
    @staticmethod
    def get_instances() -> typing.Optional[winsdk.windows.foundation.collections.IVector[AppInstance]]: ...
    def redirect_activation_to(self) -> None: ...
    @staticmethod
    def unregister() -> None: ...

class CameraApplicationManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraApplicationManager: ...
    @staticmethod
    def show_installed_applications_u_i() -> None: ...

class DesignMode(winsdk.system.Object):
    design_mode_enabled: typing.ClassVar[winsdk.system.Boolean]
    design_mode2_enabled: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DesignMode: ...

class EnteredBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnteredBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class FindRelatedPackagesOptions(winsdk.system.Object):
    relationship: PackageRelationship
    include_resources: winsdk.system.Boolean
    include_optionals: winsdk.system.Boolean
    include_host_runtimes: winsdk.system.Boolean
    include_frameworks: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FindRelatedPackagesOptions: ...
    def __new__(cls: typing.Type[FindRelatedPackagesOptions], relationship: PackageRelationship) -> FindRelatedPackagesOptions:...

class FullTrustProcessLaunchResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    launch_result: FullTrustLaunchResult
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FullTrustProcessLaunchResult: ...

class FullTrustProcessLauncher(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FullTrustProcessLauncher: ...
    @typing.overload
    @staticmethod
    def launch_full_trust_process_for_app_async(full_trust_package_relative_app_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def launch_full_trust_process_for_app_async(full_trust_package_relative_app_id: str, parameter_group_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def launch_full_trust_process_for_app_with_arguments_async(full_trust_package_relative_app_id: str, command_line: str) -> winsdk.windows.foundation.IAsyncOperation[FullTrustProcessLaunchResult]: ...
    @typing.overload
    @staticmethod
    def launch_full_trust_process_for_current_app_async() -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def launch_full_trust_process_for_current_app_async(parameter_group_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def launch_full_trust_process_for_current_app_with_arguments_async(command_line: str) -> winsdk.windows.foundation.IAsyncOperation[FullTrustProcessLaunchResult]: ...

class LeavingBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LeavingBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class LimitedAccessFeatureRequestResult(winsdk.system.Object):
    estimated_removal_date: typing.Optional[typing.Optional[datetime.datetime]]
    feature_id: str
    status: LimitedAccessFeatureStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LimitedAccessFeatureRequestResult: ...

class LimitedAccessFeatures(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LimitedAccessFeatures: ...
    @staticmethod
    def try_unlock_feature(feature_id: str, token: str, attestation: str) -> typing.Optional[LimitedAccessFeatureRequestResult]: ...

class Package(winsdk.system.Object):
    dependencies: typing.Optional[winsdk.windows.foundation.collections.IVectorView[Package]]
    id: typing.Optional[PackageId]
    installed_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    is_framework: winsdk.system.Boolean
    description: str
    display_name: str
    is_bundle: winsdk.system.Boolean
    is_development_mode: winsdk.system.Boolean
    is_resource_package: winsdk.system.Boolean
    logo: typing.Optional[winsdk.windows.foundation.Uri]
    publisher_display_name: str
    installed_date: datetime.datetime
    status: typing.Optional[PackageStatus]
    is_optional: winsdk.system.Boolean
    signature_kind: PackageSignatureKind
    effective_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    mutable_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    effective_external_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    effective_external_path: str
    effective_path: str
    installed_path: str
    is_stub: winsdk.system.Boolean
    machine_external_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    machine_external_path: str
    mutable_path: str
    user_external_location: typing.Optional[winsdk.windows.storage.StorageFolder]
    user_external_path: str
    source_uri_scheme_name: str
    install_date: datetime.datetime
    current: typing.ClassVar[typing.Optional[Package]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Package: ...
    def check_update_availability_async(self) -> winsdk.windows.foundation.IAsyncOperation[PackageUpdateAvailabilityResult]: ...
    def find_related_packages(self, options: typing.Optional[FindRelatedPackagesOptions]) -> typing.Optional[winsdk.windows.foundation.collections.IVector[Package]]: ...
    def get_app_installer_info(self) -> typing.Optional[AppInstallerInfo]: ...
    def get_app_list_entries(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.core.AppListEntry]]: ...
    def get_app_list_entries_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.core.AppListEntry]]: ...
    def get_content_group_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[PackageContentGroup]: ...
    def get_content_groups_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[PackageContentGroup]]: ...
    def get_logo_as_random_access_stream_reference(self, size: winsdk.windows.foundation.Size) -> typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    def get_thumbnail_token(self) -> str: ...
    def launch(self, parameters: str) -> None: ...
    def set_in_use_async(self, in_use: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def stage_content_groups_async(self, names: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[PackageContentGroup]]: ...
    @typing.overload
    def stage_content_groups_async(self, names: typing.Iterable[str], move_to_head_of_queue: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[PackageContentGroup]]: ...
    def verify_content_integrity_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class PackageCatalog(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageCatalog: ...
    def add_optional_package_async(self, optional_package_family_name: str) -> winsdk.windows.foundation.IAsyncOperation[PackageCatalogAddOptionalPackageResult]: ...
    def add_resource_package_async(self, resource_package_family_name: str, resource_i_d: str, options: AddResourcePackageOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[PackageCatalogAddResourcePackageResult, PackageInstallProgress]: ...
    @staticmethod
    def open_for_current_package() -> typing.Optional[PackageCatalog]: ...
    @staticmethod
    def open_for_current_user() -> typing.Optional[PackageCatalog]: ...
    @staticmethod
    def open_for_package(package: typing.Optional[Package]) -> typing.Optional[PackageCatalog]: ...
    def remove_optional_packages_async(self, optional_package_family_names: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[PackageCatalogRemoveOptionalPackagesResult]: ...
    def remove_resource_packages_async(self, resource_packages: typing.Iterable[Package]) -> winsdk.windows.foundation.IAsyncOperation[PackageCatalogRemoveResourcePackagesResult]: ...
    def add_package_installing(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageInstallingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_installing(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_package_staging(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageStagingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_staging(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_package_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageStatusChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_package_uninstalling(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageUninstallingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_uninstalling(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_package_updating(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageUpdatingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_updating(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_package_content_group_staging(self, handler: winsdk.windows.foundation.TypedEventHandler[PackageCatalog, PackageContentGroupStagingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_package_content_group_staging(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PackageCatalogAddOptionalPackageResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    package: typing.Optional[Package]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageCatalogAddOptionalPackageResult: ...

class PackageCatalogAddResourcePackageResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    package: typing.Optional[Package]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageCatalogAddResourcePackageResult: ...

class PackageCatalogRemoveOptionalPackagesResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    packages_removed: typing.Optional[winsdk.windows.foundation.collections.IVectorView[Package]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageCatalogRemoveOptionalPackagesResult: ...

class PackageCatalogRemoveResourcePackagesResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    packages_removed: typing.Optional[winsdk.windows.foundation.collections.IVectorView[Package]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageCatalogRemoveResourcePackagesResult: ...

class PackageContentGroup(winsdk.system.Object):
    is_required: winsdk.system.Boolean
    name: str
    package: typing.Optional[Package]
    state: PackageContentGroupState
    required_group_name: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageContentGroup: ...

class PackageContentGroupStagingEventArgs(winsdk.system.Object):
    activity_id: winsdk.system.Guid
    content_group_name: str
    error_code: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    is_content_group_required: winsdk.system.Boolean
    package: typing.Optional[Package]
    progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageContentGroupStagingEventArgs: ...

class PackageId(winsdk.system.Object):
    architecture: winsdk.windows.system.ProcessorArchitecture
    family_name: str
    full_name: str
    name: str
    publisher: str
    publisher_id: str
    resource_id: str
    version: PackageVersion
    author: str
    product_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageId: ...

class PackageInstallingEventArgs(winsdk.system.Object):
    activity_id: winsdk.system.Guid
    error_code: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    package: typing.Optional[Package]
    progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageInstallingEventArgs: ...

class PackageStagingEventArgs(winsdk.system.Object):
    activity_id: winsdk.system.Guid
    error_code: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    package: typing.Optional[Package]
    progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageStagingEventArgs: ...

class PackageStatus(winsdk.system.Object):
    data_offline: winsdk.system.Boolean
    dependency_issue: winsdk.system.Boolean
    deployment_in_progress: winsdk.system.Boolean
    disabled: winsdk.system.Boolean
    license_issue: winsdk.system.Boolean
    modified: winsdk.system.Boolean
    needs_remediation: winsdk.system.Boolean
    not_available: winsdk.system.Boolean
    package_offline: winsdk.system.Boolean
    servicing: winsdk.system.Boolean
    tampered: winsdk.system.Boolean
    is_partially_staged: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageStatus: ...
    def verify_is_o_k(self) -> winsdk.system.Boolean: ...

class PackageStatusChangedEventArgs(winsdk.system.Object):
    package: typing.Optional[Package]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageStatusChangedEventArgs: ...

class PackageUninstallingEventArgs(winsdk.system.Object):
    activity_id: winsdk.system.Guid
    error_code: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    package: typing.Optional[Package]
    progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageUninstallingEventArgs: ...

class PackageUpdateAvailabilityResult(winsdk.system.Object):
    availability: PackageUpdateAvailability
    extended_error: winsdk.windows.foundation.HResult
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageUpdateAvailabilityResult: ...

class PackageUpdatingEventArgs(winsdk.system.Object):
    activity_id: winsdk.system.Guid
    error_code: winsdk.windows.foundation.HResult
    is_complete: winsdk.system.Boolean
    progress: winsdk.system.Double
    source_package: typing.Optional[Package]
    target_package: typing.Optional[Package]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageUpdatingEventArgs: ...

class StartupTask(winsdk.system.Object):
    state: StartupTaskState
    task_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StartupTask: ...
    def disable(self) -> None: ...
    @staticmethod
    def get_async(task_id: str) -> winsdk.windows.foundation.IAsyncOperation[StartupTask]: ...
    @staticmethod
    def get_for_current_package_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StartupTask]]: ...
    def request_enable_async(self) -> winsdk.windows.foundation.IAsyncOperation[StartupTaskState]: ...

class SuspendingDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingDeferral: ...
    def complete(self) -> None: ...

class SuspendingEventArgs(winsdk.system.Object):
    suspending_operation: typing.Optional[SuspendingOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingEventArgs: ...

class SuspendingOperation(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingOperation: ...
    def get_deferral(self) -> typing.Optional[SuspendingDeferral]: ...

class IEnteredBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IEnteredBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ILeavingBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ILeavingBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class IPackageCatalogStatics2(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPackageCatalogStatics2: ...
    def open_for_package(self, package: typing.Optional[Package]) -> typing.Optional[PackageCatalog]: ...

class ISuspendingDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISuspendingDeferral: ...
    def complete(self) -> None: ...

class ISuspendingEventArgs(winsdk.system.Object):
    suspending_operation: typing.Optional[SuspendingOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISuspendingEventArgs: ...

class ISuspendingOperation(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISuspendingOperation: ...
    def get_deferral(self) -> typing.Optional[SuspendingDeferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media
import winsdk.windows.media.core
import winsdk.windows.storage.streams

class SpeechAppendedSilence(enum.IntEnum):
    DEFAULT = 0
    MIN = 1

class SpeechPunctuationSilence(enum.IntEnum):
    DEFAULT = 0
    MIN = 1

class VoiceGender(enum.IntEnum):
    MALE = 0
    FEMALE = 1

Self = typing.TypeVar('Self')

class SpeechSynthesisStream(winsdk.system.Object):
    timed_metadata_tracks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.core.TimedMetadataTrack]]
    markers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.IMediaMarker]]
    content_type: str
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechSynthesisStream: ...
    def clone_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], count: winsdk.system.UInt32, options: winsdk.windows.storage.streams.InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.storage.streams.IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class SpeechSynthesizer(winsdk.system.Object):
    voice: typing.Optional[VoiceInformation]
    options: typing.Optional[SpeechSynthesizerOptions]
    all_voices: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[VoiceInformation]]]
    default_voice: typing.ClassVar[typing.Optional[VoiceInformation]]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechSynthesizer: ...
    def __new__(cls: typing.Type[SpeechSynthesizer]) -> SpeechSynthesizer:...
    def close(self) -> None: ...
    def synthesize_ssml_to_stream_async(self, ssml: str) -> winsdk.windows.foundation.IAsyncOperation[SpeechSynthesisStream]: ...
    def synthesize_text_to_stream_async(self, text: str) -> winsdk.windows.foundation.IAsyncOperation[SpeechSynthesisStream]: ...
    @staticmethod
    def try_set_default_voice_async(voice: typing.Optional[VoiceInformation]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class SpeechSynthesizerOptions(winsdk.system.Object):
    include_word_boundary_metadata: winsdk.system.Boolean
    include_sentence_boundary_metadata: winsdk.system.Boolean
    speaking_rate: winsdk.system.Double
    audio_volume: winsdk.system.Double
    audio_pitch: winsdk.system.Double
    punctuation_silence: SpeechPunctuationSilence
    appended_silence: SpeechAppendedSilence
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechSynthesizerOptions: ...

class VoiceInformation(winsdk.system.Object):
    description: str
    display_name: str
    gender: VoiceGender
    id: str
    language: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceInformation: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class ContentAccessRestrictionLevel(enum.IntEnum):
    ALLOW = 0
    WARN = 1
    BLOCK = 2
    HIDE = 3

class RatedContentCategory(enum.IntEnum):
    GENERAL = 0
    APPLICATION = 1
    GAME = 2
    MOVIE = 3
    TELEVISION = 4
    MUSIC = 5

Self = typing.TypeVar('Self')

class ContentRestrictionsBrowsePolicy(winsdk.system.Object):
    geographic_region: str
    max_browsable_age_rating: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    preferred_age_rating: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContentRestrictionsBrowsePolicy: ...

class RatedContentDescription(winsdk.system.Object):
    title: str
    ratings: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    id: str
    category: RatedContentCategory
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RatedContentDescription: ...
    def __new__(cls: typing.Type[RatedContentDescription], id: str, title: str, category: RatedContentCategory) -> RatedContentDescription:...

class RatedContentRestrictions(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RatedContentRestrictions: ...
    @typing.overload
    def __new__(cls: typing.Type[RatedContentRestrictions], max_age_rating: winsdk.system.UInt32) -> RatedContentRestrictions:...
    @typing.overload
    def __new__(cls: typing.Type[RatedContentRestrictions]) -> RatedContentRestrictions:...
    def get_browse_policy_async(self) -> winsdk.windows.foundation.IAsyncOperation[ContentRestrictionsBrowsePolicy]: ...
    def get_restriction_level_async(self, rated_content_description: typing.Optional[RatedContentDescription]) -> winsdk.windows.foundation.IAsyncOperation[ContentAccessRestrictionLevel]: ...
    def request_content_access_async(self, rated_content_description: typing.Optional[RatedContentDescription]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_restrictions_changed(self, handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_restrictions_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Custom")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class DeviceAccessMode(enum.IntEnum):
    READ = 0
    WRITE = 1
    READ_WRITE = 2

class DeviceSharingMode(enum.IntEnum):
    SHARED = 0
    EXCLUSIVE = 1

class IOControlAccessMode(enum.IntEnum):
    ANY = 0
    READ = 1
    WRITE = 2
    READ_WRITE = 3

class IOControlBufferingMethod(enum.IntEnum):
    BUFFERED = 0
    DIRECT_INPUT = 1
    DIRECT_OUTPUT = 2
    NEITHER = 3

_ns_module._register_DeviceAccessMode(DeviceAccessMode)
_ns_module._register_DeviceSharingMode(DeviceSharingMode)
_ns_module._register_IOControlAccessMode(IOControlAccessMode)
_ns_module._register_IOControlBufferingMethod(IOControlBufferingMethod)

CustomDevice = _ns_module.CustomDevice
IOControlCode = _ns_module.IOControlCode
KnownDeviceTypes = _ns_module.KnownDeviceTypes
IIOControlCode = _ns_module.IIOControlCode



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Printers")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.printing
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class IppAttributeErrorReason(enum.IntEnum):
    REQUEST_ENTITY_TOO_LARGE = 0
    ATTRIBUTE_NOT_SUPPORTED = 1
    ATTRIBUTE_VALUES_NOT_SUPPORTED = 2
    ATTRIBUTE_NOT_SETTABLE = 3
    CONFLICTING_ATTRIBUTES = 4

class IppAttributeValueKind(enum.IntEnum):
    UNSUPPORTED = 0
    UNKNOWN = 1
    NO_VALUE = 2
    INTEGER = 3
    BOOLEAN = 4
    ENUM = 5
    OCTET_STRING = 6
    DATE_TIME = 7
    RESOLUTION = 8
    RANGE_OF_INTEGER = 9
    COLLECTION = 10
    TEXT_WITH_LANGUAGE = 11
    NAME_WITH_LANGUAGE = 12
    TEXT_WITHOUT_LANGUAGE = 13
    NAME_WITHOUT_LANGUAGE = 14
    KEYWORD = 15
    URI = 16
    URI_SCHEMA = 17
    CHARSET = 18
    NATURAL_LANGUAGE = 19
    MIME_MEDIA_TYPE = 20

class IppResolutionUnit(enum.IntEnum):
    DOTS_PER_INCH = 0
    DOTS_PER_CENTIMETER = 1

class PageConfigurationSource(enum.IntEnum):
    PRINT_JOB_CONFIGURATION = 0
    PDL_CONTENT = 1

_ns_module._register_IppAttributeErrorReason(IppAttributeErrorReason)
_ns_module._register_IppAttributeValueKind(IppAttributeValueKind)
_ns_module._register_IppResolutionUnit(IppResolutionUnit)
_ns_module._register_PageConfigurationSource(PageConfigurationSource)

IppAttributeError = _ns_module.IppAttributeError
IppAttributeValue = _ns_module.IppAttributeValue
IppIntegerRange = _ns_module.IppIntegerRange
IppPrintDevice = _ns_module.IppPrintDevice
IppResolution = _ns_module.IppResolution
IppSetAttributesResult = _ns_module.IppSetAttributesResult
IppTextWithLanguage = _ns_module.IppTextWithLanguage
PageConfigurationSettings = _ns_module.PageConfigurationSettings
PdlPassthroughProvider = _ns_module.PdlPassthroughProvider
PdlPassthroughTarget = _ns_module.PdlPassthroughTarget
Print3DDevice = _ns_module.Print3DDevice
PrintSchema = _ns_module.PrintSchema



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media.playback

class GraphicsTrustStatus(enum.IntEnum):
    TRUST_NOT_REQUIRED = 0
    TRUST_ESTABLISHED = 1
    ENVIRONMENT_NOT_SUPPORTED = 2
    DRIVER_NOT_SUPPORTED = 3
    DRIVER_SIGNING_FAILURE = 4
    UNKNOWN_FAILURE = 5

class HdcpProtection(enum.IntEnum):
    OFF = 0
    ON = 1
    ON_WITH_TYPE_ENFORCEMENT = 2

class HdcpSetProtectionResult(enum.IntEnum):
    SUCCESS = 0
    TIMED_OUT = 1
    NOT_SUPPORTED = 2
    UNKNOWN_FAILURE = 3

class ProtectionCapabilityResult(enum.IntEnum):
    NOT_SUPPORTED = 0
    MAYBE = 1
    PROBABLY = 2

class RenewalStatus(enum.IntEnum):
    NOT_STARTED = 0
    UPDATES_IN_PROGRESS = 1
    USER_CANCELLED = 2
    APP_COMPONENTS_MAY_NEED_UPDATING = 3
    NO_COMPONENTS_FOUND = 4

class RevocationAndRenewalReasons(enum.IntFlag):
    USER_MODE_COMPONENT_LOAD = 0x1
    KERNEL_MODE_COMPONENT_LOAD = 0x2
    APP_COMPONENT = 0x4
    GLOBAL_REVOCATION_LIST_LOAD_FAILED = 0x10
    INVALID_GLOBAL_REVOCATION_LIST_SIGNATURE = 0x20
    GLOBAL_REVOCATION_LIST_ABSENT = 0x1000
    COMPONENT_REVOKED = 0x2000
    INVALID_COMPONENT_CERTIFICATE_EXTENDED_KEY_USE = 0x4000
    COMPONENT_CERTIFICATE_REVOKED = 0x8000
    INVALID_COMPONENT_CERTIFICATE_ROOT = 0x10000
    COMPONENT_HIGH_SECURITY_CERTIFICATE_REVOKED = 0x20000
    COMPONENT_LOW_SECURITY_CERTIFICATE_REVOKED = 0x40000
    BOOT_DRIVER_VERIFICATION_FAILED = 0x100000
    COMPONENT_SIGNED_WITH_TEST_CERTIFICATE = 0x1000000
    ENCRYPTION_FAILURE = 0x10000000

Self = typing.TypeVar('Self')

class ComponentLoadFailedEventArgs(winsdk.system.Object):
    completion: typing.Optional[MediaProtectionServiceCompletion]
    information: typing.Optional[RevocationAndRenewalInformation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ComponentLoadFailedEventArgs: ...

class ComponentRenewal(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ComponentRenewal: ...
    @staticmethod
    def renew_system_components_async(information: typing.Optional[RevocationAndRenewalInformation]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[RenewalStatus, winsdk.system.UInt32]: ...

class HdcpSession(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HdcpSession: ...
    def __new__(cls: typing.Type[HdcpSession]) -> HdcpSession:...
    def close(self) -> None: ...
    def get_effective_protection(self) -> typing.Optional[typing.Optional[HdcpProtection]]: ...
    def is_effective_protection_at_least(self, protection: HdcpProtection) -> winsdk.system.Boolean: ...
    def set_desired_min_protection_async(self, protection: HdcpProtection) -> winsdk.windows.foundation.IAsyncOperation[HdcpSetProtectionResult]: ...
    def add_protection_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[HdcpSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_protection_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaProtectionManager(winsdk.system.Object):
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaProtectionManager: ...
    def __new__(cls: typing.Type[MediaProtectionManager]) -> MediaProtectionManager:...
    def add_component_load_failed(self, handler: typing.Optional[ComponentLoadFailedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_component_load_failed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_reboot_needed(self, handler: typing.Optional[RebootNeededEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_reboot_needed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_service_requested(self, handler: typing.Optional[ServiceRequestedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_service_requested(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaProtectionPMPServer(winsdk.system.Object):
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaProtectionPMPServer: ...
    def __new__(cls: typing.Type[MediaProtectionPMPServer], p_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> MediaProtectionPMPServer:...

class MediaProtectionServiceCompletion(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaProtectionServiceCompletion: ...
    def complete(self, success: winsdk.system.Boolean) -> None: ...

class ProtectionCapabilities(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ProtectionCapabilities: ...
    def __new__(cls: typing.Type[ProtectionCapabilities]) -> ProtectionCapabilities:...
    def is_type_supported(self, type: str, key_system: str) -> ProtectionCapabilityResult: ...

class RevocationAndRenewalInformation(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVector[RevocationAndRenewalItem]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RevocationAndRenewalInformation: ...

class RevocationAndRenewalItem(winsdk.system.Object):
    header_hash: str
    name: str
    public_key_hash: str
    reasons: RevocationAndRenewalReasons
    renewal_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RevocationAndRenewalItem: ...

class ServiceRequestedEventArgs(winsdk.system.Object):
    completion: typing.Optional[MediaProtectionServiceCompletion]
    request: typing.Optional[IMediaProtectionServiceRequest]
    media_playback_item: typing.Optional[winsdk.windows.media.playback.MediaPlaybackItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServiceRequestedEventArgs: ...

class IMediaProtectionServiceRequest(winsdk.system.Object):
    protection_system: winsdk.system.Guid
    type: winsdk.system.Guid
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaProtectionServiceRequest: ...

ComponentLoadFailedEventHandler = typing.Callable[[typing.Optional[MediaProtectionManager], typing.Optional[ComponentLoadFailedEventArgs]], None]

RebootNeededEventHandler = typing.Callable[[typing.Optional[MediaProtectionManager]], None]

ServiceRequestedEventHandler = typing.Callable[[typing.Optional[MediaProtectionManager], typing.Optional[ServiceRequestedEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.graphics.imaging
import winsdk.windows.media
import winsdk.windows.media.capture
import winsdk.windows.media.devices
import winsdk.windows.media.devices.core
import winsdk.windows.media.mediaproperties
import winsdk.windows.perception.spatial
import winsdk.windows.storage.streams
import winsdk.windows.ui.windowmanagement

class MediaFrameReaderAcquisitionMode(enum.IntEnum):
    REALTIME = 0
    BUFFERED = 1

class MediaFrameReaderStartStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    DEVICE_NOT_AVAILABLE = 2
    OUTPUT_FORMAT_NOT_SUPPORTED = 3
    EXCLUSIVE_CONTROL_NOT_AVAILABLE = 4

class MediaFrameSourceGetPropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    DEVICE_NOT_AVAILABLE = 3
    MAX_PROPERTY_VALUE_SIZE_TOO_SMALL = 4
    MAX_PROPERTY_VALUE_SIZE_REQUIRED = 5

class MediaFrameSourceKind(enum.IntEnum):
    CUSTOM = 0
    COLOR = 1
    INFRARED = 2
    DEPTH = 3
    AUDIO = 4
    IMAGE = 5
    METADATA = 6

class MediaFrameSourceSetPropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    INVALID_VALUE = 3
    DEVICE_NOT_AVAILABLE = 4
    NOT_IN_CONTROL = 5

class MultiSourceMediaFrameReaderStartStatus(enum.IntEnum):
    SUCCESS = 0
    NOT_SUPPORTED = 1
    INSUFFICIENT_RESOURCES = 2
    DEVICE_NOT_AVAILABLE = 3
    UNKNOWN_FAILURE = 4

Self = typing.TypeVar('Self')

class AudioMediaFrame(winsdk.system.Object):
    audio_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.AudioEncodingProperties]
    frame_reference: typing.Optional[MediaFrameReference]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioMediaFrame: ...
    def get_audio_frame(self) -> typing.Optional[winsdk.windows.media.AudioFrame]: ...

class BufferMediaFrame(winsdk.system.Object):
    buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    frame_reference: typing.Optional[MediaFrameReference]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BufferMediaFrame: ...

class DepthMediaFrame(winsdk.system.Object):
    depth_format: typing.Optional[DepthMediaFrameFormat]
    frame_reference: typing.Optional[MediaFrameReference]
    video_media_frame: typing.Optional[VideoMediaFrame]
    max_reliable_depth: winsdk.system.UInt32
    min_reliable_depth: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DepthMediaFrame: ...
    def try_create_coordinate_mapper(self, camera_intrinsics: typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics], coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]) -> typing.Optional[winsdk.windows.media.devices.core.DepthCorrelatedCoordinateMapper]: ...

class DepthMediaFrameFormat(winsdk.system.Object):
    depth_scale_in_meters: winsdk.system.Double
    video_format: typing.Optional[VideoMediaFrameFormat]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DepthMediaFrameFormat: ...

class InfraredMediaFrame(winsdk.system.Object):
    frame_reference: typing.Optional[MediaFrameReference]
    is_illuminated: winsdk.system.Boolean
    video_media_frame: typing.Optional[VideoMediaFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InfraredMediaFrame: ...

class MediaFrameArrivedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameArrivedEventArgs: ...

class MediaFrameFormat(winsdk.system.Object):
    frame_rate: typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]
    major_type: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    subtype: str
    video_format: typing.Optional[VideoMediaFrameFormat]
    audio_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.AudioEncodingProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameFormat: ...

class MediaFrameReader(winsdk.system.Object):
    acquisition_mode: MediaFrameReaderAcquisitionMode
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameReader: ...
    def close(self) -> None: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameReaderStartStatus]: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_acquire_latest_frame(self) -> typing.Optional[MediaFrameReference]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaFrameReader, MediaFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaFrameReference(winsdk.system.Object):
    buffer_media_frame: typing.Optional[BufferMediaFrame]
    coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]
    duration: datetime.timedelta
    format: typing.Optional[MediaFrameFormat]
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    source_kind: MediaFrameSourceKind
    system_relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    video_media_frame: typing.Optional[VideoMediaFrame]
    audio_media_frame: typing.Optional[AudioMediaFrame]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameReference: ...
    def close(self) -> None: ...

class MediaFrameSource(winsdk.system.Object):
    controller: typing.Optional[MediaFrameSourceController]
    current_format: typing.Optional[MediaFrameFormat]
    info: typing.Optional[MediaFrameSourceInfo]
    supported_formats: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaFrameFormat]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameSource: ...
    def set_format_async(self, format: typing.Optional[MediaFrameFormat]) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_get_camera_intrinsics(self, format: typing.Optional[MediaFrameFormat]) -> typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics]: ...
    def add_format_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_format_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaFrameSourceController(winsdk.system.Object):
    video_device_controller: typing.Optional[winsdk.windows.media.devices.VideoDeviceController]
    audio_device_controller: typing.Optional[winsdk.windows.media.devices.AudioDeviceController]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameSourceController: ...
    def get_property_async(self, property_id: str) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameSourceGetPropertyResult]: ...
    def get_property_by_extended_id_async(self, extended_property_id: winsdk.system.Array[winsdk.system.UInt8], max_property_value_size: typing.Optional[winsdk.system.UInt32]) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameSourceGetPropertyResult]: ...
    def set_property_async(self, property_id: str, property_value: typing.Optional[winsdk.system.Object]) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameSourceSetPropertyStatus]: ...
    def set_property_by_extended_id_async(self, extended_property_id: winsdk.system.Array[winsdk.system.UInt8], property_value: winsdk.system.Array[winsdk.system.UInt8]) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameSourceSetPropertyStatus]: ...

class MediaFrameSourceGetPropertyResult(winsdk.system.Object):
    status: MediaFrameSourceGetPropertyStatus
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameSourceGetPropertyResult: ...

class MediaFrameSourceGroup(winsdk.system.Object):
    display_name: str
    id: str
    source_infos: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaFrameSourceInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameSourceGroup: ...
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[MediaFrameSourceGroup]]: ...
    @staticmethod
    def from_id_async(id: str) -> winsdk.windows.foundation.IAsyncOperation[MediaFrameSourceGroup]: ...
    @staticmethod
    def get_device_selector() -> str: ...

class MediaFrameSourceInfo(winsdk.system.Object):
    coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]
    device_information: typing.Optional[winsdk.windows.devices.enumeration.DeviceInformation]
    id: str
    media_stream_type: winsdk.windows.media.capture.MediaStreamType
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    source_group: typing.Optional[MediaFrameSourceGroup]
    source_kind: MediaFrameSourceKind
    profile_id: str
    video_profile_media_description: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.capture.MediaCaptureVideoProfileMediaDescription]]
    is_shareable: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaFrameSourceInfo: ...
    def get_relative_panel(self, display_region: typing.Optional[winsdk.windows.ui.windowmanagement.DisplayRegion]) -> winsdk.windows.devices.enumeration.Panel: ...

class MultiSourceMediaFrameArrivedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MultiSourceMediaFrameArrivedEventArgs: ...

class MultiSourceMediaFrameReader(winsdk.system.Object):
    acquisition_mode: MediaFrameReaderAcquisitionMode
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MultiSourceMediaFrameReader: ...
    def close(self) -> None: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncOperation[MultiSourceMediaFrameReaderStartStatus]: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_acquire_latest_frame(self) -> typing.Optional[MultiSourceMediaFrameReference]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[MultiSourceMediaFrameReader, MultiSourceMediaFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MultiSourceMediaFrameReference(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MultiSourceMediaFrameReference: ...
    def close(self) -> None: ...
    def try_get_frame_reference_by_source_id(self, source_id: str) -> typing.Optional[MediaFrameReference]: ...

class VideoMediaFrame(winsdk.system.Object):
    camera_intrinsics: typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics]
    depth_media_frame: typing.Optional[DepthMediaFrame]
    direct3_d_surface: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]
    frame_reference: typing.Optional[MediaFrameReference]
    infrared_media_frame: typing.Optional[InfraredMediaFrame]
    software_bitmap: typing.Optional[winsdk.windows.graphics.imaging.SoftwareBitmap]
    video_format: typing.Optional[VideoMediaFrameFormat]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoMediaFrame: ...
    def get_video_frame(self) -> typing.Optional[winsdk.windows.media.VideoFrame]: ...

class VideoMediaFrameFormat(winsdk.system.Object):
    depth_format: typing.Optional[DepthMediaFrameFormat]
    height: winsdk.system.UInt32
    media_frame_format: typing.Optional[MediaFrameFormat]
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoMediaFrameFormat: ...

